@@ -234,7 +234,7 @@ class DatabaseClient():
         if pretty: res = parseResults(res)
         return res
 
-    def resolveAppsyncQuery(self, schema="", secretArn=None, client_type=None, switch_role=None):
+    def resolveAppsyncQuery(self, schema="", secretArn=None, client_type=None, switch_role=None, event=None):
         """Run a query for each item in event
 
         This is a wrapper for DatabaseClient.resolveInstanceAppsyncQuery and DatabaseClient.resolveServerlessAppsyncQuery and
@@ -268,7 +268,7 @@ class DatabaseClient():
                 dbClient = DatabaseClient(event=event, config=config, client_type="serverless")
                 return dbClient.resolveAppsyncQuery()
         """
-
+        if event is not None: self.event = event
         if client_type is None:
             client_type = self.client_type
         if client_type == "serverless":
